@@ -23,19 +23,9 @@ import os
 
 OCRFEEDER_STUDIO_NAME = 'OCRFeeder'
 OCRFEEDER_COMPACT_NAME = 'ocrfeeder'
-OCRFEEDER_STUDIO_VERSION = '0.6.1'
+OCRFEEDER_STUDIO_VERSION = '0.6.5'
 OCRFEEDER_STUDIO_AUTHORS = ['Joaquim Rocha <joaquimrocha1@gmail.com>']
 OCRFEEDER_STUDIO_ARTISTS = ['Joaquim Rocha <joaquimrocha1@gmail.com>']
-OCRFEEDER_STUDIO_TRANSLATORS = [('English', 'Joaquim Rocha <joaquimrocha1@gmail.com>'),
-                                ('Portuguese', 'Joaquim Rocha <joaquimrocha1@gmail.com>'),
-                                ('German', 'Renard Voß <renardvoss@gmx.de>'),
-                                ('Italian', 'Andrea Grandi <a.grandi@gmail.com>'),
-                                ('French', 'Philippe Normand <phil@base-art.net>'),
-                                ('Galician', 'Xabier Rodríguez Calvar <xrcalvar@igalia.com>'),
-                                ('Spanish', 'Andrés Gómez <agomez@igalia.com>'),
-                                ('Simplified Chinese', '刘洪德 (Hongde Liu) <enginespot@gmail.com>'),
-                                ('Swedish', 'Daniel Nylander <po@danielnylander.se>'),
-                               ]
 OCRFEEDER_COPYRIGHT = 'Copyright © 2008-2010 Joaquim Rocha\n' \
                       'Copyright © 2009-2010 Igalia, SL'
 OCRFEEDER_WEBSITE = 'http://live.gnome.org/OCRFeeder'
